import { EventEmitter, SimpleChanges, OnChanges } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "@angular/common";
/**
 * Avatar represents people using icons, labels and images.
 * @group Components
 */
export declare class Avatar implements OnChanges {
    /**
     * Defines the text to display.
     * @group Props
     */
    label: string | undefined;
    /**
     * Defines the icon to display.
     * @group Props
     */
    icon: string | undefined;
    /**
     * Defines the image to display.
     * @group Props
     */
    image: string | undefined;
    /**
     * Size of the element.
     * @group Props
     */
    size: 'normal' | 'large' | 'xlarge' | undefined;
    /**
     * Shape of the element.
     * @group Props
     */
    shape: 'square' | 'circle' | undefined;
    /**
     * Inline style of the element.
     * @group Props
     */
    style: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Class of the element.
     * @group Props
     */
    styleClass: string | undefined;
    /**
     * Establishes a string value that labels the component.
     * @group Props
     */
    ariaLabel: string | undefined;
    /**
     * Establishes relationships between the component and label(s) where its value should be one or more element IDs.
     * @group Props
     */
    ariaLabelledBy: string | undefined;
    /**
     * This event is triggered if an error occurs while loading an image file.
     * @param {Event} event - Browser event.
     * @group Emits
     */
    onImageError: EventEmitter<Event>;
    /**
     * Holds the current style of the component to allow dynamic updates.
     */
    currentStyle: {
        [klass: string]: any;
    } | null | undefined;
    containerClass(): {
        'p-avatar p-component': boolean;
        'p-avatar-image': boolean;
        'p-avatar-circle': boolean;
        'p-avatar-lg': boolean;
        'p-avatar-xl': boolean;
    };
    /**
     * Lifecycle hook to detect changes in inputs.
     */
    ngOnChanges(changes: SimpleChanges): void;
    imageError(event: Event): void;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<Avatar, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<Avatar, "p-avatar", never, { "label": { "alias": "label"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "image": { "alias": "image"; "required": false; }; "size": { "alias": "size"; "required": false; }; "shape": { "alias": "shape"; "required": false; }; "style": { "alias": "style"; "required": false; }; "styleClass": { "alias": "styleClass"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "ariaLabelledBy": { "alias": "ariaLabelledBy"; "required": false; }; }, { "onImageError": "onImageError"; }, never, ["*"], false, never>;
}
export declare class AvatarModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<AvatarModule, [typeof Avatar], [typeof i1.CommonModule], [typeof Avatar]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<AvatarModule>;
}
